#[non_exhaustive]pub struct RNG<'a> { /* private fields */ }unstable only.Expand description
RNG peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl RNG<'_>
impl RNG<'_>
Sourcepub const fn regs<'a>() -> &'a RngRegisterBlock
pub const fn regs<'a>() -> &'a RngRegisterBlock
Returns a reference to the register block.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn register_block(&self) -> &RngRegisterBlock
pub fn register_block(&self) -> &RngRegisterBlock
Returns a reference to the register block.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourceimpl RNG<'_>
impl RNG<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely creates an instance of this peripheral out of thin air.
Safety
The caller must ensure that only one instance of this type is used at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
The caller must ensure that only one instance of this type is used at a time.